@@ -11,7 +11,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD %EXPORT_TAGS @EXPORT_FAIL
 require DynaLoader;
 
 @ISA = qw(DynaLoader);
-$VERSION = '1.042';
+$VERSION = '1.043';
 
 @_param = qw(
 	PARAM_BOUNDARY	PARAM_CHANNEL	PARAM_COLOR	PARAM_DISPLAY	PARAM_DRAWABLE
@@ -32,16 +32,16 @@ $VERSION = '1.042';
 	GRAY_CHANNEL	GRAY_IMAGE	GREEN_CHANNEL	HUE_MODE	IMAGE_CLONE
 	INDEXED		INDEXEDA_IMAGE	INDEXED_CHANNEL	INDEXED_IMAGE	LIGHTEN_ONLY_MODE
 	LINEAR		MULTIPLY_MODE	NORMAL_MODE	NO_IMAGE_FILL	OVERLAY_MODE
-	PATTERN_BUCKET_FILL		PATTERN_CLONE	PIXELS		POINTS
+	PATTERN_CLONE	PIXELS		POINTS		PATTERN_BUCKET_FILL
 	PROC_EXTENSION	PROC_PLUG_IN	PROC_TEMPORARY	RADIAL		RED_CHANNEL
-	REPEAT_NONE	REPEAT_SAWTOOTH	REPEAT_TRIANGULAR		RGB
+	REPEAT_NONE	REPEAT_SAWTOOTH	FG_IMAGE_FILL	WHITE_MASK	REPEAT_TRIANGULAR
 	RGBA_IMAGE	RGB_IMAGE	RUN_INTERACTIVE	RUN_NONINTERACTIVE
-	RUN_WITH_LAST_VALS		SATURATION_MODE	SCREEN_MODE	SELECTION_ADD
+	SATURATION_MODE	SCREEN_MODE	SELECTION_ADD	RGB		RUN_WITH_LAST_VALS
 	SELECTION_INTERSECT		SELECTION_REPLACE		SELECTION_SUB
 	SHAPEBURST_ANGULAR		SHAPEBURST_DIMPLED		SHAPEBURST_SPHERICAL
 	SHARPEN		SQUARE		STATUS_CALLING_ERROR		STATUS_EXECUTION_ERROR
 	STATUS_PASS_THROUGH		STATUS_SUCCESS	SUBTRACT_MODE	TRANS_IMAGE_FILL
-	VALUE_MODE	DIVIDE_MODE	WHITE_MASK	WHITE_IMAGE_FILL
+	VALUE_MODE	DIVIDE_MODE	WHITE_IMAGE_FILL
 	
 	TRACE_NONE	TRACE_CALL	TRACE_TYPE	TRACE_NAME	TRACE_DESC
 	TRACE_ALL
@@ -53,6 +53,8 @@ $VERSION = '1.042';
 	
 	ALL_HUES	RED_HUES	YELLOW_HUES	GREEN_HUES	CYAN_HUES
 	BLUE_HUES	MAGENTA_HUES
+	
+	HORIZONTAL	VERTICAL
 ));
 
 @_procs = qw(
@@ -82,6 +84,9 @@ sub SHADOWS		(){ 0 };
 sub MIDTONES		(){ 1 };
 sub HIGHLIGHTS		(){ 2 };
 
+sub HORIZONTAL		(){ 0 };
+sub VERTICAL		(){ 1 };
+
 # internal constants shared with Perl-Server
 
 sub _PS_FLAG_QUIET	{ 0000000001 };	# do not output messages
